"use strict";
var magazineSaga = magazineSaga || {};

!(function ($) {
    let loadButtonWrapper = $(".magazine-saga-load-posts-btn-wrapper");
    let loadButton = $(".magazine-saga-load-posts-btn-wrapper .load-btn");
    let loader = $(
        ".magazine-saga-load-posts-btn-wrapper .magazine-saga-ajax-loader"
    );

    let currentPage = parseInt(loadButtonWrapper.attr("data-page"));
    let nextPage = currentPage + 1;
    let maxPage = parseInt(loadButtonWrapper.attr("data-max-pages"));

    let loadType = loadButtonWrapper.attr("data-load-type");
    let template = loadButtonWrapper.closest("#primary").attr("data-template");

    let canBeLoaded = true;

    magazineSaga.loadMorePosts = {
        fetchPostsOnClick: function () {
            $(loadButton).on("click", function (event) {
                event.preventDefault();
                fetchThePosts();
            });
        },

        fetchPostsOnScroll: function () {
            let offset =
                $(loadButtonWrapper).offset().top - $(window).scrollTop();
            if (nextPage <= maxPage) {
                if (700 > offset && canBeLoaded) {
                    fetchThePosts();
                }
            }
        },
    };

    function fetchThePosts() {
        $.ajax({
            type: "POST",
            url: MagazineSagaVars.ajaxurl,
            data: {
                action: "magazine_saga_load_posts",
                load_post_nonce: MagazineSagaVars.load_post_nonce,
                query_vars: MagazineSagaVars.query_vars,
                page: nextPage,
                template: template,
            },
            dataType: "json",
            beforeSend: function () {
                loadButton.hide();
                loader.addClass("active");

                canBeLoaded = false;
            },
            success: function (response) {
                if (response.success) {
                    let contentJoin = response.data.content.join("");
                    let content = $(contentJoin);
                    content.hide();

                    $(".magazine-saga-posts-lists").append(content);

                    // Set Background Image if any
                    if (contentJoin.indexOf("magazine-saga-bg-image") >= 0) {
                        magazineSaga.setBackgroundImage.init();
                    }

                    currentPage = nextPage;
                    nextPage++;

                    loader.removeClass("active");
                    content.fadeIn();

                    if (nextPage <= maxPage) {
                        if ("ajax_load_on_click" == loadType) {
                            loadButton.fadeIn();
                        }
                    } else {
                        loadButtonWrapper.hide();
                    }

                    canBeLoaded = true;

                    $(document.body).trigger("posts-loaded");
                } else {
                    loader.removeClass("active");
                }
            },
        });
    }

    $(document).ready(function () {
        if ($(".magazine-saga-load-posts-btn-wrapper").length > 0) {
            // Hide Normal Pagination
            $(".magazine-saga-nav-pagination .posts-navigation").hide();

            // Load Posts on Click
            if ("ajax_load_on_click" == loadType) {
                loadButtonWrapper.css("display", "flex");
                magazineSaga.loadMorePosts.fetchPostsOnClick();
            }
        }
    });

    // Load Posts on Scroll
    if ("ajax_load_on_scroll" == loadType) {
        loadButtonWrapper.css("display", "flex");
        loadButton.hide();
        $(window).scroll(function () {
            magazineSaga.loadMorePosts.fetchPostsOnScroll();
        });
    }
})(jQuery);
