<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Magazine_Saga
 */

$wrapper_classes = $footer_bg_image = $overlay_div = '';

if ( get_theme_mod( 'enable_border_above_footer' ) ) {
	$wrapper_classes .= ' border-enabled';
}

/*Footer Background Image*/
if ( get_theme_mod( 'enable_footer_bg_image' ) ) {
	$has_footer_bg_image = get_theme_mod( 'footer_bg_image' );
	if ( $has_footer_bg_image ) {
		$footer_bg_image = 'background-image:url(' . esc_url( $has_footer_bg_image ) . ')';
		$footer_bg_image = 'style="' . esc_attr( $footer_bg_image ) . '"';

		$wrapper_classes .= ' footer-bg-enabled';

		if ( get_theme_mod( 'footer_fixed_bg_image' ) ) {
			$wrapper_classes .= ' magazine-saga-bg-attachment-fixed';
		}

		$overlay_style  = 'background-color:' . get_theme_mod( 'footer_bg_image_overlay_color', '#000000' ) . ';';
		$overlay_style .= 'opacity:' . get_theme_mod( 'footer_bg_image_opacity', '0.5' ) . ';';

		$overlay_div = '<span aria-hidden="true" class="footer-bg-overlay" style="' . esc_attr( $overlay_style ) . '"></span>';
	}
}

// Inverted Footer.
if ( 'dark' == get_theme_mod( 'footer_theme', 'dark' ) ) {
	$wrapper_classes .= ' inverted-footer';
}

$heading_style = ' saga-title-style-' . get_theme_mod( 'footer_widget_heading_style', 'style_4' );
$heading_align = ' saga-title-align-' . get_theme_mod( 'footer_widget_heading_align', 'left' );

$wrapper_classes .= $heading_style . $heading_align;

?>

<?php do_action( 'magazine_saga_before_footer' ); ?>

<?php get_template_part( 'template-parts/footer/before-footer' ); ?>

<?php get_template_part( 'template-parts/footer/before-footer-no-container' ); ?>

<footer id="colophon" class="site-footer<?php echo esc_attr( $wrapper_classes ); ?>" <?php echo $footer_bg_image; ?>>

	<?php echo $overlay_div; ?>

	<div class="wrapper">

		<?php get_template_part( 'template-parts/footer/footer-widgets' ); ?>

		<?php get_template_part( 'template-parts/footer/footer-info' ); ?>
		
	</div><!-- wrapper -->

</footer><!-- #colophon -->

<?php get_template_part( 'template-parts/footer/after-footer' ); ?>

<?php get_template_part( 'template-parts/footer/after-footer-no-container' ); ?>

<?php do_action( 'magazine_saga_after_footer' ); ?>

<?php
if ( get_theme_mod( 'enable_scroll_to_top', true ) ) {
	$pos = get_theme_mod( 'scroll_to_top_pos', 'right' );
	?>
	<a id="magazine-saga-scroll-to-top" href="#" class="fill-children-current-color <?php echo esc_attr( $pos )?>">
		<?php magazine_saga_the_theme_svg( 'chevron-up' ); ?>
	</a>
	<?php
}
?>
	</div><!-- #site-content-wrapper -->
</div><!-- #page -->

<?php do_action( 'magazine_saga_after_site' ); ?>

<?php
if ( get_theme_mod( 'enable_search_on_top_bar', true ) || get_theme_mod( 'enable_search_on_menu_bar' ) || get_theme_mod( 'enable_search_on_header' ) ) :
	get_template_part( 'template-parts/header/search-modal' );
endif;
?>

<?php get_template_part( 'template-parts/header/canvas-modal' ); ?>

<?php wp_footer(); ?>

</body>
</html>
