<?php

$widgets_link = admin_url( 'widgets.php' );

$wp_customize->add_section(
	'footer_options',
	array(
		'title' => __( 'Footer Options', 'magazine-saga' ),
		'panel' => 'footer_options_panel',
	)
);

// Footer Theme.
$wp_customize->add_setting(
	'footer_theme',
	array(
		'default'           => $theme_options_defaults['footer_theme'],
		'sanitize_callback' => 'magazine_saga_sanitize_select',
	)
);
$wp_customize->add_control(
	'footer_theme',
	array(
		'label'   => __( 'Footer Theme', 'magazine-saga' ),
		'section' => 'footer_options',
		'type'    => 'select',
		'choices' => array(
			'light' => __( 'Light', 'magazine-saga' ),
			'dark'   => __( 'Dark', 'magazine-saga' ),
		),
	)
);

// Light Footer Background Color.
$wp_customize->add_setting(
	'footer_bg_color',
	array(
		'default'           => $theme_options_defaults['footer_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'footer_bg_color',
		array(
			'label'   => __( 'Light Theme Background', 'magazine-saga' ),
			'section' => 'footer_options',
			'type'    => 'color',
			'active_callback' => 'magazine_saga_is_light_footer',
		)
	)
);

// Dark Footer Background Color.
$wp_customize->add_setting(
	'dark_footer_bg_color',
	array(
		'default'           => $theme_options_defaults['dark_footer_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'dark_footer_bg_color',
		array(
			'label'   => __( 'Dark Theme Background', 'magazine-saga' ),
			'section' => 'footer_options',
			'type'    => 'color',
			'active_callback' => 'magazine_saga_is_dark_footer',
		)
	)
);

// Option to choose footer column layout.
$wp_customize->add_setting(
	'footer_column_layout',
	array(
		'default'           => $theme_options_defaults['footer_column_layout'],
		'sanitize_callback' => 'magazine_saga_sanitize_radio',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Radio_Image_Control(
		$wp_customize,
		'footer_column_layout',
		array(
			'label'       => __( 'Footer Column Layout', 'magazine-saga' ),
			'description' => __('Some footer widgetareas will not be used based on the footer column layout chosen. Also make sure to insert at least one widget on the respective widgetarea for it to display.', 'magazine-saga'),
			'section'     => 'footer_options',
			'choices'     => magazine_saga_get_footer_layouts(),
		)
	)
);

/* Footer Widget heading style */
$wp_customize->add_setting(
	'footer_widget_heading_style',
	array(
		'default'           => $theme_options_defaults['footer_widget_heading_style'],
		'sanitize_callback' => 'magazine_saga_sanitize_select',
	)
);
$wp_customize->add_control(
	'footer_widget_heading_style',
	array(
		'label'   => __( 'Footer Widgets Title Style', 'magazine-saga' ),
		'section' => 'footer_options',
		'type'    => 'select',
		'choices' => magazine_saga_get_title_styles(),
	)
);

/* Footer Widget heading Align */
$wp_customize->add_setting(
	'footer_widget_heading_align',
	array(
		'default'           => $theme_options_defaults['footer_widget_heading_align'],
		'sanitize_callback' => 'magazine_saga_sanitize_select',
	)
);
$wp_customize->add_control(
	'footer_widget_heading_align',
	array(
		'label'   => __( 'Footer Widgets Title Alignment', 'magazine-saga' ),
		'section' => 'footer_options',
		'type'    => 'select',
		'choices' => magazine_saga_get_title_alignments(),
	)
);

// Enable Footer Background Image.
$wp_customize->add_setting(
	'enable_footer_bg_image',
	array(
		'default'           => $theme_options_defaults['enable_footer_bg_image'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_footer_bg_image',
		array(
			'label'   => __( 'Enable Footer Background Image', 'magazine-saga' ),
			'section' => 'footer_options',
		)
	)
);

// Footer background Image.
$wp_customize->add_setting(
	'footer_bg_image',
	array(
		'default'           => $theme_options_defaults['footer_bg_image'],
		'sanitize_callback' => 'magazine_saga_sanitize_image',
	)
);
$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'footer_bg_image',
		array(
			'label'           => __( 'Footer Background Image', 'magazine-saga' ),
			'section'         => 'footer_options',
			'active_callback' => 'magazine_saga_is_footer_bg_enabled',
		)
	)
);

// Footer Background Image Overlay Color.
$wp_customize->add_setting(
	'footer_bg_image_overlay_color',
	array(
		'default'           => $theme_options_defaults['footer_bg_image_overlay_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'footer_bg_image_overlay_color',
		array(
			'label'           => __( 'Image Overlay', 'magazine-saga' ),
			'section'         => 'footer_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_footer_bg_enabled',
		)
	)
);

// Footer background Image Opacity.
$wp_customize->add_setting(
	'footer_bg_image_opacity',
	array(
		'default'           => $theme_options_defaults['footer_bg_image_opacity'],
		'sanitize_callback' => 'magazine_saga_sanitize_float',
	)
);
$wp_customize->add_control(
	'footer_bg_image_opacity',
	array(
		'label'           => __( 'Overlay Opacity', 'magazine-saga' ),
		'section'         => 'footer_options',
		'type'            => 'number',
		'input_attrs'     => array(
			'min'   => 0,
			'max'   => 1,
			'step'  => 0.1,
			'style' => 'width: 150px;',
		),
		'active_callback' => 'magazine_saga_is_footer_bg_enabled',
	)
);

// Enable Fixed Footer Background Image.
$wp_customize->add_setting(
	'footer_fixed_bg_image',
	array(
		'default'           => $theme_options_defaults['footer_fixed_bg_image'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'footer_fixed_bg_image',
		array(
			'label'           => __( 'Fixed Image Background', 'magazine-saga' ),
			'section'         => 'footer_options',
			'active_callback' => 'magazine_saga_is_footer_bg_enabled',
		)
	)
);

// Enable Border Top.
$wp_customize->add_setting(
	'enable_border_above_footer',
	array(
		'default'           => $theme_options_defaults['enable_border_above_footer'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_border_above_footer',
		array(
			'label'   => __( 'Enable a Border Above Footer', 'magazine-saga' ),
			'section' => 'footer_options',
		)
	)
);

// Enable Border above footer info
$wp_customize->add_setting(
	'enable_border_above_footer_info',
	array(
		'default'           => $theme_options_defaults['enable_border_above_footer_info'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_border_above_footer_info',
		array(
			'label'   => __( 'Enable a Border Above Footer Info', 'magazine-saga' ),
			'section' => 'footer_options',
		)
	)
);

/*Enable copyright*/
$wp_customize->add_setting(
	'enable_copyright',
	array(
		'default'           => $theme_options_defaults['enable_copyright'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_copyright',
        array(
            'label'   => __( 'Enable Copyright', 'magazine-saga' ),
            'section' => 'footer_options',
        )
	)
);

/*Copyright Text.*/
$wp_customize->add_setting(
	'copyright_text',
	array(
		'default'           => $theme_options_defaults['copyright_text'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'copyright_text',
	array(
		'label'           => __( 'Copyright Text', 'magazine-saga' ),
		'section'         => 'footer_options',
		'type'            => 'text',
		'active_callback' => 'magazine_saga_is_copyright_enabled',
	)
);

/*Todays Date Format*/
$wp_customize->add_setting(
	'copyright_date_format',
	array(
		'default'           => $theme_options_defaults['copyright_date_format'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'copyright_date_format',
	array(
		'label'           => __( 'Todays Date Format', 'magazine-saga' ),
		'description'     => sprintf(
			wp_kses(
				__( '<a href="%s" target="_blank">Date and Time Formatting Documentation</a>.', 'magazine-saga' ),
				array(
					'a' => array(
						'href'   => array(),
						'target' => array(),
					),
				)
			),
			esc_url( 'https://wordpress.org/support/article/formatting-date-and-time' )
		),
		'section'         => 'footer_options',
		'type'            => 'text',
		'active_callback' => 'magazine_saga_is_copyright_enabled',
	)
);

/*Enable footer credit*/
$wp_customize->add_setting(
	'enable_footer_credit',
	array(
		'default'           => $theme_options_defaults['enable_footer_credit'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_footer_credit',
        array(
            'label'   => __( 'Enable Footer Credit', 'magazine-saga' ),
            'section' => 'footer_options',
            'type'    => 'checkbox',
        )
	)
);

/*Enable Footer Nav*/
$wp_customize->add_setting(
	'enable_footer_nav',
	array(
		'default'           => $theme_options_defaults['enable_footer_nav'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_footer_nav',
        array(
            'label'       => __( 'Show Footer Nav Menu', 'magazine-saga' ),
            'description' => sprintf( __( 'You can add/edit footer nav menu from <a href="%s">here</a>.', 'magazine-saga' ), "javascript:wp.customize.control( 'nav_menu_locations[footer-menu]' ).focus();" ),
            'section'     => 'footer_options',
        )
	)
);

/*Enable Footer Social Nav*/
$wp_customize->add_setting(
	'enable_footer_social_nav',
	array(
		'default'           => $theme_options_defaults['enable_footer_social_nav'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_footer_social_nav',
        array(
            'label'       => __( 'Show Social Nav Menu in Footer', 'magazine-saga' ),
            'description' => sprintf( __( 'You can add/edit social nav menu from <a href="%s">here</a>.', 'magazine-saga' ), "javascript:wp.customize.control( 'nav_menu_locations[social-menu]' ).focus();" ),
            'section'     => 'footer_options',
        )
	)
);

// Social Links Brand Color.
$wp_customize->add_setting(
	'footer_social_links_color',
	array(
		'default'           => $theme_options_defaults['footer_social_links_color'],
		'sanitize_callback' => 'magazine_saga_sanitize_select',
	)
);
$wp_customize->add_control(
	'footer_social_links_color',
	array(
		'label'   => __( 'Social Links Color', 'magazine-saga' ),
		'section' => 'footer_options',
		'type'    => 'select',
		'choices' => array(
			'theme_color' => __( 'Use Theme Color', 'magazine-saga' ),
			'brand_color'   => __( 'Use Brand Color', 'magazine-saga' ),
		),
		'active_callback' => 'magazine_saga_is_footer_social_menu_enabled',
	)
);

// Social Links Display Style.
$wp_customize->add_setting(
	'footer_social_links_display_style',
	array(
		'default'           => $theme_options_defaults['footer_social_links_display_style'],
		'sanitize_callback' => 'magazine_saga_sanitize_select',
	)
);
$wp_customize->add_control(
	'footer_social_links_display_style',
	array(
		'label'   => __( 'Social Links Display Style', 'magazine-saga' ),
		'section' => 'footer_options',
		'type'    => 'select',
		'choices' => magazine_saga_get_social_links_styles(),
		'active_callback' => 'magazine_saga_is_footer_social_menu_enabled',
	)
);

