<?php
$wp_customize->add_section(
	'topbar_options',
	array(
		'title' => __( 'Topbar Options', 'magazine-saga' ),
		'panel' => 'header_options_panel',
	)
);

/*Enable Top Bar*/
$wp_customize->add_setting(
	'show_top_bar',
	array(
		'default'           => $theme_options_defaults['show_top_bar'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'show_top_bar',
		array(
			'label'   => __( 'Enable Top Bar', 'magazine-saga' ),
			'section' => 'topbar_options',
		)
	)
);

/*Hide Top Bar on Mobile*/
$wp_customize->add_setting(
	'hide_top_bar_mobile',
	array(
		'default'           => $theme_options_defaults['hide_top_bar_mobile'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'hide_top_bar_mobile',
		array(
			'label'           => __( 'Hide Top Bar on Mobile', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

/*Enable Today's Date*/
$wp_customize->add_setting(
	'enable_todays_date',
	array(
		'default'           => $theme_options_defaults['enable_todays_date'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_todays_date',
		array(
			'label'           => __( 'Enable Today\'s Date', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

/*Todays Date Format*/
$wp_customize->add_setting(
	'todays_date_format',
	array(
		'default'           => $theme_options_defaults['todays_date_format'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control(
	'todays_date_format',
	array(
		'label'           => __( 'Today\'s Date Format', 'magazine-saga' ),
		'description'     => sprintf(
			wp_kses(
				__( '<a href="%s" target="_blank">Date and Time Formatting Documentation</a>.', 'magazine-saga' ),
				array(
					'a' => array(
						'href'   => array(),
						'target' => array(),
					),
				)
			),
			esc_url( 'https://wordpress.org/support/article/formatting-date-and-time' )
		),
		'section'         => 'topbar_options',
		'type'            => 'text',
		'active_callback' => function( $control ) {
			return (
				magazine_saga_is_top_bar_enabled( $control )
				&&
				magazine_saga_is_todays_date_enabled( $control )
			);
		},
	)
);

/*Enable Top Social Nav*/
$wp_customize->add_setting(
	'show_top_bar_social_nav',
	array(
		'default'           => $theme_options_defaults['show_top_bar_social_nav'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'show_top_bar_social_nav',
		array(
			'label'           => __( 'Enable Top Bar Social Nav Menu', 'magazine-saga' ),
			'description'     => sprintf( __( 'You can add/edit social nav menu from <a href="%s">here</a>.', 'magazine-saga' ), "javascript:wp.customize.control( 'nav_menu_locations[social-menu]' ).focus();" ),
			'section'         => 'topbar_options',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

/*Enable Top Nav*/
$wp_customize->add_setting(
	'show_top_bar_nav',
	array(
		'default'           => $theme_options_defaults['show_top_bar_nav'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'show_top_bar_nav',
		array(
			'label'           => __( 'Enable Top Bar Nav Menu', 'magazine-saga' ),
			'description'     => sprintf( __( 'You can add/edit top nav menu from <a href="%s">here</a>.', 'magazine-saga' ), "javascript:wp.customize.control( 'nav_menu_locations[top-menu]' ).focus();" ),
			'section'         => 'topbar_options',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

/*Enable Search*/
$wp_customize->add_setting(
	'enable_search_on_top_bar',
	array(
		'default'           => $theme_options_defaults['enable_search_on_top_bar'],
		'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
	)
);
$wp_customize->add_control(
	new Magazine_Saga_Toggle_Control(
		$wp_customize,
		'enable_search_on_top_bar',
		array(
			'label'   => __( 'Enable Search Icon', 'magazine-saga' ),
			'section' => 'topbar_options',
			'active_callback' => 'magazine_saga_is_top_bar_enabled'
		)
	)
);

if ( magazine_saga_is_wc_active() ) {

	/*Enable Mini Cart Icon on Top Bar*/
	$wp_customize->add_setting(
		'enable_woo_mini_cart_top_bar',
		array(
			'default'           => $theme_options_defaults['enable_woo_mini_cart_top_bar'],
			'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new Magazine_Saga_Toggle_Control(
			$wp_customize,
			'enable_woo_mini_cart_top_bar',
			array(
				'label'           => __( 'Enable Mini Cart Icon', 'magazine-saga' ),
				'section'         => 'topbar_options',
				'active_callback' => 'magazine_saga_is_top_bar_enabled',
			)
		)
	);

	/*Enable Myaccount Link Top Bar*/
	$wp_customize->add_setting(
		'enable_woo_my_account_top_bar',
		array(
			'default'           => $theme_options_defaults['enable_woo_my_account_top_bar'],
			'sanitize_callback' => 'magazine_saga_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new Magazine_Saga_Toggle_Control(
			$wp_customize,
			'enable_woo_my_account_top_bar',
			array(
				'label'           => __( 'Enable My Account Icon', 'magazine-saga' ),
				'section'         => 'topbar_options',
				'active_callback' => 'magazine_saga_is_top_bar_enabled',
			)
		)
	);

}

/*Top Bar background Color*/
$wp_customize->add_setting(
	'top_bar_bg_color',
	array(
		'default'           => $theme_options_defaults['top_bar_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'top_bar_bg_color',
		array(
			'label'           => __( 'Top Bar Background Color', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

// Top Bar Date Color
$wp_customize->add_setting(
	'top_bar_date_color',
	array(
		'default'           => $theme_options_defaults['top_bar_date_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'top_bar_date_color',
		array(
			'label'           => __( 'Top Bar Date Color', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

// Top Bar Nav Menu Color
$wp_customize->add_setting(
	'top_bar_nav_menu_color',
	array(
		'default'           => $theme_options_defaults['top_bar_nav_menu_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'top_bar_nav_menu_color',
		array(
			'label'           => __( 'Top Bar Nav Menu Color', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

// Top Bar Nav Menu Hover Color
$wp_customize->add_setting(
	'top_bar_nav_menu_hover_color',
	array(
		'default'           => $theme_options_defaults['top_bar_nav_menu_hover_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'top_bar_nav_menu_hover_color',
		array(
			'label'           => __( 'Top Bar Nav Menu Hover Color', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);

/*Top Bar Sub Menu Background Color*/
$wp_customize->add_setting(
	'top_bar_sub_menu_bg_color',
	array(
		'default'           => $theme_options_defaults['top_bar_sub_menu_bg_color'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);
$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'top_bar_sub_menu_bg_color',
		array(
			'label'           => __( 'Top Bar Sub Menu Background Color', 'magazine-saga' ),
			'section'         => 'topbar_options',
			'type'            => 'color',
			'active_callback' => 'magazine_saga_is_top_bar_enabled',
		)
	)
);
