<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Magazine_Saga
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function magazine_saga_body_classes( $classes ) {

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Get Sticky menu.
	$sticky_menu = get_theme_mod( 'enable_sticky_menu', true );
	if ( $sticky_menu ) {
		$classes[] = 'has-sticky-menu';
	}

	// Get Header Style.
	$classes[] = get_theme_mod( 'header_style', 'header_style_1' );

	// Get appropriate class for the sidebar layout.
	$page_layout = magazine_saga_get_page_layout();
	if ( 'no-sidebar' == $page_layout ) {
		$classes[] = 'no-sidebar wide-container';
	} elseif ( 'no-sidebar-narrow' == $page_layout ) {
		$classes[] = 'no-sidebar narrow-container';
	} else {
		$classes[] = 'has-sidebar ' . esc_attr( $page_layout );
	}

	// Get Sticky.
	if ( is_front_page() ) {
		$sticky = get_theme_mod( 'front_page_sticky_sidebar', true );
	} else {
		$sticky = get_theme_mod( 'sticky_sidebar', true );
	}
	if ( $sticky ) {
		$classes[] = 'has-sticky-sidebar';
	}

	// Get theme component style.
	$classes[] = 'component_' . esc_attr( get_theme_mod( 'theme_component_style', 'style_1' ) );

	return $classes;
}
add_filter( 'body_class', 'magazine_saga_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function magazine_saga_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'magazine_saga_pingback_header' );
