<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Saga_Ads_Code extends Magazine_Saga_Widget_Base {
	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->widget_cssclass    = 'magazine_saga_ads_code_widget';
		$this->widget_description = __( 'Advertisements or codes widget.', 'magazine-saga' );
		$this->widget_id          = 'magazine_saga_ads_code_widget';
		$this->widget_name        = __( 'Magazine Saga: Ads Code', 'magazine-saga' );
		$this->settings           = array(
			'ads_code'        => array(
				'type'  => 'textarea',
				'label' => __( 'Ads Code', 'magazine-saga' ),
			),
			'align'           => array(
				'type'    => 'select',
				'label'   => __( 'Alignment', 'magazine-saga' ),
				'options' => array(
					'left'    => __( 'Left', 'magazine-saga' ),
					'center'  => __( 'Center', 'magazine-saga' ),
					'right'   => __( 'Right', 'magazine-saga' ),
					'strecth' => __( 'Stretch', 'magazine-saga' ),
				),
				'std'     => 'center',
			),
			'hide_on_desktop' => array(
				'type'  => 'checkbox',
				'label' => __( 'Hide on Desktop', 'magazine-saga' ),
				'std'   => false,
			),
			'hide_on_tablet'  => array(
				'type'  => 'checkbox',
				'label' => __( 'Hide on Tablet', 'magazine-saga' ),
				'std'   => false,
			),
			'hide_on_mobile'  => array(
				'type'  => 'checkbox',
				'label' => __( 'Hide on Mobile', 'magazine-saga' ),
				'std'   => false,
			),
		);

		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {

		ob_start();

		$before_widget = $args['before_widget'];
		$after_widget  = $args['after_widget'];

		echo wp_kses_post( $before_widget );

		$ad_class = '';
		if ( $instance['hide_on_desktop'] ) {
			$ad_class .= ' hide-on-desktop';
		}
		if ( $instance['hide_on_tablet'] ) {
			$ad_class .= ' hide-on-tablet';
		}
		if ( $instance['hide_on_mobile'] ) {
			$ad_class .= ' hide-on-mobile';
		}

		do_action( 'magazine_saga_before_ads_code' );

		?>

		<div class="magazine-saga-ads-code-widget<?php echo esc_attr( $ad_class ); ?>" style="justify-items:<?php echo esc_attr( $instance['align'] ); ?>;" >
			<?php
			if ( $instance['ads_code'] ) {
				echo wp_kses_post( $instance['ads_code'] );
			}
			?>
		</div>

		<?php

		do_action( 'magazine_saga_after_ads_code' );

		echo wp_kses_post( $after_widget );

		echo ob_get_clean();
	}

}
