<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Saga_Mailchimp_Form extends Magazine_Saga_Widget_Base {

	/**
	 * Constructor.
	 */
	public function __construct() {
		 $this->widget_cssclass   = 'widget_magazine_saga_mailchimp_form';
		$this->widget_description = __( 'Displays MailChimp form if you have any', 'magazine-saga' );
		$this->widget_id          = 'magazine_saga_mailchimp_form';
		$this->widget_name        = __( 'Magazine Saga: MailChimp Form', 'magazine-saga' );
		$this->settings           = array(
			'title'                      => array(
				'type'  => 'text',
				'label' => __( 'Widget Title', 'magazine-saga' ),
			),
			'mailchimp_settings_heading' => array(
				'type'  => 'heading',
				'label' => __( 'Mailchimp Settings', 'magazine-saga' ),
			),
			'mailchimp_title'            => array(
				'type'  => 'text',
				'label' => __( 'Mailchimp Title', 'magazine-saga' ),
			),
			'desc'                       => array(
				'type'  => 'textarea',
				'label' => __( 'Description', 'magazine-saga' ),
				'rows'  => 10,
			),
			'form_shortcode'             => array(
				'type'  => 'text',
				'label' => __( 'MailChimp Form Shortcode', 'magazine-saga' ),
			),
			'widget_settings_heading'    => array(
				'type'  => 'heading',
				'label' => __( 'Widget Settings', 'magazine-saga' ),
			),
			'style'                      => array(
				'type'    => 'select',
				'label'   => __( 'Style', 'magazine-saga' ),
				'options' => array(
					'style_1' => __( 'Items Aligned Left', 'magazine-saga' ),
					'style_2' => __( 'Items Aligned Center', 'magazine-saga' ),
					'style_3' => __( 'Items Aligned Center + Wide Submit Button', 'magazine-saga' ),
				),
				'std'     => 'style_1',
			),
			'enable_bg_color'            => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Background Color', 'magazine-saga' ),
				'std'   => false,
			),
			'bg_color'                   => array(
				'type'  => 'color',
				'label' => __( 'Background Color', 'magazine-saga' ),
				'std'   => '#000000',
				'desc'  => __( 'Will be overridden if used background image.', 'magazine-saga' ),
			),
			'bg_image'                   => array(
				'type'  => 'image',
				'label' => __( 'Background Image', 'magazine-saga' ),
				'desc'  => __( 'Don\'t upload any image if you do not want to show the background image.', 'magazine-saga' ),
			),
			'enable_fixed_bg'            => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Fixed Background Image', 'magazine-saga' ),
				'std'   => true,
			),
			'bg_overlay_color'           => array(
				'type'  => 'color',
				'label' => __( 'Overlay Color', 'magazine-saga' ),
				'std'   => '#000000',
			),
			'overlay_opacity'            => array(
				'type'  => 'number',
				'step'  => 10,
				'min'   => 0,
				'max'   => 100,
				'std'   => 50,
				'label' => __( 'Overlay Opacity', 'magazine-saga' ),
			),
			'height'                     => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 150,
				'max'   => '',
				'std'   => 350,
				'label' => __( 'Height (px)', 'magazine-saga' ),
				'desc'  => __( 'Works when there is either a background color or image.', 'magazine-saga' ),
			),
		);
		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		if ( ! empty( $instance['form_shortcode'] ) ) {

			ob_start();

			$style         = '';
			$class         = $instance['style'];
			$image_enabled = false;

			$this->widget_start( $args, $instance );

			if ( $instance['enable_bg_color'] ) {
				$bg_color = isset( $instance['bg_color'] ) ? $instance['bg_color'] : $this->settings['bg_color']['std'];
				$style    = 'background-color:' . esc_attr( $bg_color ) . ';';
			}

			if ( ( $instance['bg_image'] && 0 != $instance['bg_image'] ) ) {
				$image_enabled = true;
				if ( $instance['enable_fixed_bg'] ) {
					$class .= ' magazine-saga-bg-image magazine-saga-bg-attachment-fixed';
				}
			}

			if ( $instance['enable_bg_color'] || $image_enabled ) {
				$height = isset( $instance['height'] ) ? $instance['height'] : $this->settings['height']['std'];
				$style  .= 'min-height:' . esc_attr( $height ) . 'px;';
				$class .= ' magazine-saga-cover-block';
			}

			do_action( 'magazine_saga_before_mailchimp' );

			?>
			
			<div class="magazine-saga-mailchimp-widget <?php echo esc_attr( $class ); ?>" style="<?php echo esc_attr( $style ); ?>">

				<?php
				if ( $image_enabled ) {
					$overlay_style  = 'background-color:' . $instance['bg_overlay_color'] . ';';
					$overlay_style .= 'opacity:' . ( $instance['overlay_opacity'] / 100 ) . ';';
					?>
					<span aria-hidden="true" class="magazine-saga-block-overlay" style="<?php echo esc_attr( $overlay_style ); ?>"></span>
					<?php echo wp_get_attachment_image( $instance['bg_image'], 'full' ); ?>
					<?php
				}
				?>
				<div class="magazine-saga-mailchimp-inner-wrapper magazine-saga-block-inner-wrapper">

					<?php if ( $instance['mailchimp_title'] ) : ?>
						<h3 class="mailchimp-title">
							<?php echo esc_html( $instance['mailchimp_title'] ); ?>
						</h3>
					<?php endif; ?>

					<?php if ( $instance['desc'] ) : ?>
						<div class="mailchimp-desc">
							<?php echo wpautop( wp_kses_post( $instance['desc'] ) ); ?>
						</div>
					<?php endif; ?>
					
					<?php echo do_shortcode( $instance['form_shortcode'] ); ?>

				</div>

			</div>

			<?php

			do_action( 'magazine_saga_after_mailchimp' );

			$this->widget_end( $args );

			echo ob_get_clean();
		}
	}
}
