<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Saga_Post_Categories_Grid extends Magazine_Saga_Widget_Base {

	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->widget_cssclass    = 'magazine_saga_post_categories_grid_widget';
		$this->widget_description = __( 'Displays post categories with image in grid', 'magazine-saga' );
		$this->widget_id          = 'magazine_saga_post_categories_grid_widget';
		$this->widget_name        = __( 'Magazine Saga: Post Categories Grid', 'magazine-saga' );

		$post_categories = array();
		$categories      = get_categories(
			array(
				'orderby' => 'name',
				'order'   => 'ASC',
			)
		);

		if ( ! empty( $categories ) ) {
			foreach ( $categories as $cat ) {
				$post_categories[ $cat->term_id ] = $cat->name;
			}
		}

		$this->settings = array(
			'title'           => array(
				'type'  => 'text',
				'label' => __( 'Title', 'magazine-saga' ),
			),
			'categories'      => array(
				'type'    => 'multi-checkbox',
				'label'   => __( 'Select Categories', 'magazine-saga' ),
				'options' => $post_categories,
			),
			'no_of_column'    => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => 5,
				'std'   => 2,
				'label' => __( 'Number of Column', 'magazine-saga' ),
			),
			'display_style'   => array(
				'type'    => 'select',
				'label'   => __( 'Display Style', 'magazine-saga' ),
				'options' => array(
					'style_1' => __( 'Default', 'magazine-saga' ),
					'style_2' => __( 'Category on Bottom', 'magazine-saga' ),
					'style_3' => __( 'Category on Center', 'magazine-saga' ),
					'style_4' => __( 'Small Height', 'magazine-saga' ),
				),
				'std'     => 'style_1',
			),
			'overlay_color'   => array(
				'type'  => 'color',
				'label' => __( 'Overlay Color', 'magazine-saga' ),
				'std'   => '#000000',
			),
			'overlay_opacity' => array(
				'type'  => 'number',
				'step'  => 10,
				'min'   => 0,
				'max'   => 100,
				'std'   => 50,
				'label' => __( 'Overlay Opacity', 'magazine-saga' ),
			),
		);

		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {

		ob_start();

		if ( ! empty( $instance['categories'] ) ) {

			$this->widget_start( $args, $instance );

			do_action( 'magazine_saga_before_post_cat_grid' );

			$column = $instance['no_of_column'];
			$style  = $instance['display_style'];

			$col_class = 'row row-cols-1 row-cols-sm-2 g-3';

			if ( 2 == $column ) {
				$col_class .= ' magazine-saga-grid-2';
			} elseif ( 3 == $column ) {
				$col_class .= ' row-cols-md-2 row-cols-lg-3 magazine-saga-grid-3';
			} elseif ( 4 == $column ) {
				$col_class .= ' row-cols-md-2 row-cols-xl-4 magazine-saga-grid-4';
			} elseif ( 5 == $column ) {
				$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-saga-grid-5';
			} else {
				$col_class = ' row row-cols-1 g-3';
			}

			$img_size = 'magazine-saga-large-img';

			?>

			<div class="magazine-saga-posts-categories-grid-widget <?php echo esc_attr( $style ); ?>">
				<div class="<?php echo esc_attr( $col_class ); ?>">
					<?php
					foreach ( $instance['categories'] as $category ) {
						$cat_info = get_category( $category );
						if ( ! empty( $cat_info ) && ! is_wp_error( $cat_info ) ) {
							$term_link        = get_category_link( $category );
							$thumbnail_id     = get_term_meta( $category, 'thumbnail_id', true );
							$image_attributes = wp_get_attachment_image_src( $thumbnail_id, $img_size );
							if ( $image_attributes ) {
								$style  = 'background-color:' . $instance['overlay_color'] . ';';
								$style .= 'opacity:' . ( $instance['overlay_opacity'] / 100 ) . ';';
								?>
								<div class="col">
									<div class="saga-block-item-w-overlay img-animate-zoom">
										<div class="saga-block-image-w-overlay">
											<a href="<?php echo esc_url( $term_link ); ?>" class="">
											<span aria-hidden="true" class="magazine-saga-block-overlay" style="<?php echo esc_attr( $style ); ?>"></span>
												<img src="<?php echo esc_url( $image_attributes[0] ); ?>">
											</a>
										</div>
										<div class="saga-block-overlay-content">
											<h3 class="saga-block-overlay-title">
												<a href="<?php echo esc_url( $term_link ); ?>" class="text-decoration-none">
													<?php echo esc_html( $cat_info->name ); ?>
												</a>
											</h3>
										</div>
									</div>
								</div>
								<?php
							}
						}
					}
					?>
				</div>
			</div>
			<?php

			do_action( 'magazine_saga_after_post_cat_grid' );

			$this->widget_end( $args );

		}

		echo ob_get_clean();
	}

}
