<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Magazine_Saga_Posts_Carousel extends Magazine_Saga_Widget_Base {

	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->widget_cssclass    = 'widget_magazine_saga_posts_carousel';
		$this->widget_description = __( 'Displays posts in carousel', 'magazine-saga' );
		$this->widget_id          = 'magazine_saga_posts_carousel';
		$this->widget_name        = __( 'Magazine Saga: Posts Carousel', 'magazine-saga' );
		$this->settings           = array(
			'title'                     => array(
				'type'  => 'text',
				'label' => __( 'Title', 'magazine-saga' ),
			),
			'post_settings_heading'     => array(
				'type'  => 'heading',
				'label' => __( 'Post Settings', 'magazine-saga' ),
			),
			'category'                  => array(
				'type'  => 'dropdown-taxonomies',
				'label' => __( 'Select Category', 'magazine-saga' ),
				'desc'  => __( 'Leave empty if you don\'t want the posts to be category specific', 'magazine-saga' ),
				'args'  => array(
					'taxonomy'        => 'category',
					'class'           => 'widefat',
					'hierarchical'    => true,
					'show_count'      => 1,
					'show_option_all' => __( '&mdash; Select &mdash;', 'magazine-saga' ),
				),
			),
			'number'                    => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 5,
				'label' => __( 'Number of posts to show', 'magazine-saga' ),
			),
			'orderby'                   => array(
				'type'    => 'select',
				'std'     => 'date',
				'label'   => __( 'Order by', 'magazine-saga' ),
				'options' => array(
					'date'  => __( 'Date', 'magazine-saga' ),
					'ID'    => __( 'ID', 'magazine-saga' ),
					'title' => __( 'Title', 'magazine-saga' ),
					'rand'  => __( 'Random', 'magazine-saga' ),
				),
			),
			'order'                     => array(
				'type'    => 'select',
				'std'     => 'desc',
				'label'   => __( 'Order', 'magazine-saga' ),
				'options' => array(
					'asc'  => __( 'ASC', 'magazine-saga' ),
					'desc' => __( 'DESC', 'magazine-saga' ),
				),
			),
			'category_settings_heading' => array(
				'type'  => 'heading',
				'label' => __( 'Category Settings', 'magazine-saga' ),
			),
			'show_category'             => array(
				'type'  => 'checkbox',
				'label' => __( 'Show Category', 'magazine-saga' ),
			),
			'category_color'            => array(
				'type'    => 'select',
				'label'   => __( 'Category Color', 'magazine-saga' ),
				'options' => magazine_saga_get_category_color_display(),
				'std'     => 'none',
			),
			'category_style'            => array(
				'type'    => 'select',
				'label'   => __( 'Category Style', 'magazine-saga' ),
				'options' => magazine_saga_get_category_styles(),
				'std'     => 'style_1',
			),
			'no_of_category'            => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 0,
				'max'   => '',
				'std'   => 1,
				'label' => __( 'Number of Category to Display', 'magazine-saga' ),
			),
			'widget_settings_heading'   => array(
				'type'  => 'heading',
				'label' => __( 'Widget Settings', 'magazine-saga' ),
			),
			'display_style'             => array(
				'type'    => 'select',
				'std'     => 'style_1',
				'label'   => __( 'Display Style', 'magazine-saga' ),
				'options' => array(
					'style_1' => __( 'Style 1', 'magazine-saga' ),
					'style_2' => __( 'Style 2', 'magazine-saga' ),
				),
			),
			'margin'                    => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 0,
				'max'   => 100,
				'std'   => 10,
				'label' => __( 'Carousel margin', 'magazine-saga' ),
			),
			'autoplay'                  => array(
				'type'  => 'checkbox',
				'label' => __( 'Autoplay', 'magazine-saga' ),
			),
			'column'                    => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => 5,
				'std'   => 3,
				'label' => __( 'Column', 'magazine-saga' ),
			),
			'enable_post_format_icon'   => array(
				'type'  => 'checkbox',
				'label' => __( 'Enable Post Format Icon', 'magazine-saga' ),
				'std'   => false,
			),
			'title_limit'               => array(
				'type'    => 'select',
				'label'   => __( 'Post Title Limit', 'magazine-saga' ),
				'options' => magazine_saga_get_title_limit_choices(),
				'std'     => '',
			),
		);

		parent::__construct();
	}

	/**
	 * Query the posts and return them.
	 *
	 * @param  array $args
	 * @param  array $instance
	 * @return WP_Query
	 */
	public function get_posts( $args, $instance ) {
		$number  = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
		$orderby = ! empty( $instance['orderby'] ) ? sanitize_title( $instance['orderby'] ) : $this->settings['orderby']['std'];
		$order   = ! empty( $instance['order'] ) ? sanitize_title( $instance['order'] ) : $this->settings['order']['std'];

		$query_args = array(
			'posts_per_page'      => $number,
			'post_status'         => 'publish',
			'no_found_rows'       => 1,
			'orderby'             => $orderby,
			'order'               => $order,
			'ignore_sticky_posts' => 1,
		);

		if ( ! empty( $instance['category'] ) && -1 != $instance['category'] && 0 != $instance['category'] ) {
			$query_args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'term_id',
				'terms'    => $instance['category'],
			);
		}

		return new WP_Query( apply_filters( 'magazine_saga_posts_carousel_query_args', $query_args ) );
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {

		ob_start();

		if ( ( $posts = $this->get_posts( $args, $instance ) ) && $posts->have_posts() ) {
			$this->widget_start( $args, $instance );

			do_action( 'magazine_saga_before_posts_carousel' );

			$display_style = $instance['display_style'];

			$margin         = absint( $instance['margin'] );
			$autoplay       = $instance['autoplay'];
			$column         = absint( $instance['column'] );
			$display_style .= " column-$column";

			// Build attributes.
			$data_slider        = array();
			$data_slider_option = '';

			$data_slider[] = '"spaceBetween": ' . $margin . '';

			if ( $autoplay ) :
				$data_slider[] = '"autoplay": {"delay": 5000}';
			endif;

			if ( $column == 2 ) {
				$data_slider[] = '"breakpoints": {"576": {"slidesPerView": 2}}';
			} elseif ( $column == 3 ) {
				$data_slider[] = '"breakpoints": {"576": {"slidesPerView": 2}, "768": {"slidesPerView": 3} }';
			} elseif ( $column == 4 ) {
				$data_slider[] = '"breakpoints": {"576": {"slidesPerView": 2}, "768": {"slidesPerView": 3}, "992": {"slidesPerView": 4} }';
			} elseif ( $column == 5 ) {
				$data_slider[] = '"breakpoints": {"576": {"slidesPerView": 2}, "768": {"slidesPerView": 3}, "992": {"slidesPerView": 4}, "1200": {"slidesPerView": 5} }';
			}

			if ( ! empty( $data_slider ) ) :
				$data_slider_option = trim( implode( ', ', $data_slider ) );
			endif;

			$show_category = $instance['show_category'];
			if ( $show_category ) {
				$cat_style = $instance['category_style'];
				$color     = $instance['category_color'];
				$limit     = $instance['no_of_category'];
			}
			$title_limit             = isset( $instance['title_limit'] ) ? $instance['title_limit'] : $this->settings['title_limit']['std'];
			$enable_post_format_icon = isset( $instance['enable_post_format_icon'] ) ? $instance['enable_post_format_icon'] : $this->settings['enable_post_format_icon']['std'];
			?>

			<div class="magazine-saga-carousel-wrapper <?php echo esc_attr( $display_style ); ?>">
				<div class="swiper" data-slider='{<?php echo $data_slider_option; ?>}'>
					<div class="swiper-wrapper">
						<?php
						while ( $posts->have_posts() ) :
							$posts->the_post();
							if ( has_post_thumbnail() ) {
								?>
								<div class="swiper-slide">
									<div class="article-block-wrapper img-animate-zoom">
										<div class="article-image">
											<a href="<?php the_permalink(); ?>">
												<?php
												if ( $enable_post_format_icon ) {
													magazine_saga_post_format_icon( 'center' );
												}
												?>
												<?php
												the_post_thumbnail(
													'magazine-saga-large-img',
													array(
														'alt' => the_title_attribute(
															array(
																'echo' => false,
															)
														),
													)
												);
												?>
											</a>
										</div>
										<div class="article-details magazine-saga-card-box">
											<?php
											if ( $show_category ) {
												echo '<div class="article-cat-info">';
												magazine_saga_post_categories( $cat_style, $color, $limit );
												echo '</div>';
											}
											?>
											<h3 class="article-title no-margin">
												<a href="<?php the_permalink(); ?>" class="text-decoration-none magazine-saga-limit-lines <?php echo esc_attr( $title_limit ); ?>">
													<?php the_title(); ?>
												</a>
											</h3>
										</div>
									</div>
								</div>
								<?php
							}
						endwhile;
						wp_reset_postdata();
						?>
					</div>
					<div class="swiper-button-next"></div>
					<div class="swiper-button-prev"></div>
				</div>
			</div>

			<?php

			do_action( 'magazine_saga_after_posts_carousel' );

			$this->widget_end( $args );
		}

		echo ob_get_clean();
	}

}
