<?php
/**
 * Template part for displaying post archives
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Magazine_Saga
 */

$enabled_post_meta = get_theme_mod( 'archive_post_meta', array( 'author', 'date', 'comment', 'category' ) );
set_query_var( 'enabled_post_meta', $enabled_post_meta );

$cats_enabled  = false;
$meta_settings = array(
	'date_format'  => get_theme_mod( 'archive_date_format', 'format_2' ),
	'author_image' => get_theme_mod( 'enable_archive_author_image' ),
);

// Build category.
if ( in_array( 'category', $enabled_post_meta ) ) {
	$cats_enabled = true;
	$cat_style    = get_theme_mod( 'archive_category_style', 'style_1' );
	$cat_color    = get_theme_mod( 'archive_category_color_display', 'none' );
	$cat_limit    = get_theme_mod( 'archive_category_limit', 3 );
	$cat_label    = get_theme_mod( 'enable_archive_cat_label', true );
}

$show_post_format_icon = get_theme_mod( 'show_archive_post_format_icon' );
$archive_title_limit   = get_theme_mod( 'archive_posts_title_limit' );

// Use custom query if available.
global $wp_query;
$custom_archive_query = isset( $archive_query ) ? $archive_query : $wp_query;
while ( $custom_archive_query->have_posts() ) :
	$custom_archive_query->the_post();
	?>

	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="saga-block-item-w-overlay img-animate-zoom">
			<div class="saga-block-image-w-overlay">
				<a href="<?php the_permalink(); ?>">
					<?php
					if ( $show_post_format_icon ) :
						magazine_saga_post_format_icon();
					endif;
					?>
					<span aria-hidden="true" class="magazine-saga-block-overlay"></span>
					<?php the_post_thumbnail( 'magazine-saga-large-img' ); ?>
				</a>
			</div>
			<div class="saga-block-overlay-content">
				<?php
				if ( $cats_enabled && 'post' === get_post_type() ) :
					magazine_saga_post_categories( $cat_style, $cat_color, $cat_limit, $cat_label );
				endif;
				?>
				<h2 class="saga-block-overlay-title">
					<a href="<?php the_permalink(); ?>" class="text-decoration-none magazine-saga-limit-lines <?php echo esc_attr( $archive_title_limit ); ?>"><?php the_title(); ?></a>
				</h2>
				<?php if ( 'post' === get_post_type() ) : ?>
					<div class="entry-meta">
						<?php magazine_saga_post_meta_info( $enabled_post_meta, $meta_settings ); ?>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</article><!-- #post-<?php the_ID(); ?> -->

	<?php
endwhile;
wp_reset_postdata();
