<?php
$post_args = array(
	'post_type'           => 'post',
	'post_status'         => 'publish',
	'no_found_rows'       => 1,
	'ignore_sticky_posts' => 1,
);

$banner_content_from = get_theme_mod( 'banner_content_from', 'category' );

if ( 'category' == $banner_content_from ) :

	$slider_cat                  = get_theme_mod( 'slider_cat', 1 );
	$banner_posts_orderby        = esc_attr( get_theme_mod( 'banner_posts_orderby', 'date' ) );
	$post_args['posts_per_page'] = absint( get_theme_mod( 'no_of_banner_posts', 4 ) );
	$post_args['orderby']        = ( 'id' == $banner_posts_orderby ) ? strtoupper( $banner_posts_orderby ) : $banner_posts_orderby;
	$post_args['order']          = esc_attr( get_theme_mod( 'banner_posts_order', 'desc' ) );

	if ( ! empty( $slider_cat ) ) :
		$post_args['tax_query'][] = array(
			'taxonomy' => 'category',
			'field'    => 'term_id',
			'terms'    => absint( $slider_cat ),
		);
	endif;

else :

	$banner_post_ids = get_theme_mod( 'banner_post_ids' );
	if ( ! empty( $banner_post_ids ) ) :
		$post_ids                    = explode( ',', esc_attr( $banner_post_ids ) );
		$post_args['post__in']       = $post_ids;
		$post_args['orderby']        = 'post__in';
		$post_args['posts_per_page'] = count( $post_ids );
	endif;

endif;

$banner_posts = new WP_Query( $post_args );
if ( $banner_posts->have_posts() ) :

	// Empty container class for full width banner.
	$container_class = $slider_wrapper_class = '';

	// Holds banner attributes.
	$data_banner = array();

	// Default image size.
	$image_size = 'magazine-saga-cover-image';

	$enable_banner_dots = $enable_banner_arrows = '';

	$banner_layout         = get_theme_mod( 'banner_layout', 'boxed' );
	$banner_display_as     = get_theme_mod( 'banner_display_as', 'slider' );
	$enable_banner_arrows  = get_theme_mod( 'enable_banner_arrows', true );
	$enable_banner_dots    = get_theme_mod( 'enable_banner_dots', true );
	$enable_banner_overlay = get_theme_mod( 'enable_banner_overlay', true );
	if ( $enable_banner_overlay ) {
		$banner_overlay_style  = 'background-color:' . esc_attr( get_theme_mod( 'banner_overlay_color', '#000000' ) ) . ';';
		$banner_overlay_style .= 'opacity:' . esc_attr( get_theme_mod( 'banner_overlay_opacity', 0.6 ) ) . ';';
	}
	$show_banner_category = get_theme_mod( 'show_banner_category' );
	if ( $show_banner_category ) {
		$banner_cat_style = get_theme_mod( 'banner_category_style', 'style_2' );
		$banner_cat_color = get_theme_mod( 'banner_category_color_display', 'none' );
		$banner_cat_limit = get_theme_mod( 'banner_category_limit', 3 );
	}
	$banner_post_meta          = get_theme_mod( 'banner_post_meta' );
	$banner_post_meta_settings = array(
		'date_format'  => get_theme_mod( 'banner_posts_date_format', 'format_2' ),
		'author_image' => get_theme_mod( 'enable_banner_author_image' ),
	);

	$enable_pinned_posts = get_theme_mod( 'enable_pinned_posts', true );

	// Wrapper class for non full width banner.
	if ( 'boxed' == $banner_layout ) :
		$container_class = ' wide-max-width';
		if ( $enable_pinned_posts ) :
			$image_size           = 'magazine-saga-large-img';
			$slider_wrapper_class = 'col-lg-8';
		else :
			$slider_wrapper_class = 'col-lg-12';
		endif;
	endif;

	if ( 'full-width' == $banner_layout ) :
		$enable_pinned_posts  = false;
		$image_size           = 'magazine-saga-cover-image';
		$slider_wrapper_class = 'col-lg-12';
	endif;

	if ( 'slider' == $banner_display_as ) :

		$display_style = get_theme_mod( 'banner_slider_style', 'style_1' );
		$banner_style  = 'as-slider ' . $display_style;

		$data_banner['effect']     = 'fade';
		$data_banner['fadeEffect'] = array(
			'crossFade' => true,
		);

	else :

		$display_style = get_theme_mod( 'banner_carousel_style', 'style_1' );
		$banner_style  = 'as-carousel ' . $display_style;

		$data_banner['slidesPerView']  = 1.1;
		$data_banner['centeredSlides'] = true;
		$data_banner['keyboard']       = array(
			'enabled' => true,
		);
		$data_banner['spaceBetween']   = 10;
		$data_banner['breakpoints']    = array(
			'800' => array(
				'slidesPerView' => 1.5,
			),
		);

	endif;

	if ( $enable_banner_arrows ) :
		$data_banner['navigation'] = array(
			'nextEl' => '.swiper-button-next',
			'prevEl' => '.swiper-button-prev',
		);
	endif;

	if ( $enable_banner_dots ) :
		$data_banner['pagination'] = array(
			'el'        => '.swiper-pagination',
			'clickable' => true,
		);
	endif;

	if ( get_theme_mod( 'enable_banner_autoplay', true ) ) :
		$data_banner['auoplay'] = array(
			'delay' => 5000,
		);
	endif;

	$wrapper_class = $banner_layout . ' ' . $banner_style;

	?>
	<section class="magazine-saga-section-banner-wrapper <?php echo esc_attr( $wrapper_class ); ?>">
		<div class="magazine-saga-section-banner<?php echo esc_attr( $container_class ); ?>">
			<div class="row<?php echo esc_attr( 'full-width' == $banner_layout ) ? ' gy-0' : ' g-3'; ?>">
				<div class="col <?php echo esc_attr( $slider_wrapper_class ); ?>">
					<?php
					$banner_title = get_theme_mod( 'banner_title' );
					if ( ! empty( $banner_title ) ) :
						$title_style = get_theme_mod( 'banner_title_style', 'style_1' );
						$title_align = 'has-text-align-' . get_theme_mod( 'banner_title_align', 'left' );
						?>
						<div class="saga-section-title">
							<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
								<span><?php echo esc_html( $banner_title ); ?></span>
							</h2>
						</div>
					<?php endif; ?>
					<div class="magazine-saga-banner-wrapper swiper" data-banner='<?php echo esc_attr( json_encode( $data_banner ) ); ?>'>
						<div class="magazine-saga-banner swiper-wrapper">
							<?php
							$title_limit = get_theme_mod( 'banner_posts_title_limit' );
							while ( $banner_posts->have_posts() ) :
								$banner_posts->the_post();
								if ( has_post_thumbnail() ) :
									?>
									<div class="swiper-slide">
										<div class="banner-block-wrapper img-animate-zoom">
											<div class="banner-image">
												<a href="<?php the_permalink(); ?>">
													<?php if ( $enable_banner_overlay ) : ?>
														<span aria-hidden="true" class="magazine-saga-block-overlay" style="<?php echo $banner_overlay_style; ?>"></span>
													<?php endif; ?>
													<?php
													the_post_thumbnail(
														$image_size,
														array(
															'alt' => the_title_attribute(
																array(
																	'echo' => false,
																)
															),
														)
													);
													?>
												</a>
											</div>
											<div class="banner-caption">
												<div class="banner-caption-inner">
													<?php
													if ( $show_banner_category ) :
														magazine_saga_post_categories( $banner_cat_style, $banner_cat_color, $banner_cat_limit );
													endif;
													?>
													<h3 class="banner-title no-margin">
														<a href="<?php the_permalink(); ?>" class="text-decoration-none magazine-saga-limit-lines <?php echo esc_attr( $title_limit ); ?>">
															<?php the_title(); ?>
														</a>
													</h3>
													<?php magazine_saga_post_meta_info( $banner_post_meta, $banner_post_meta_settings ); ?>
												</div>
											</div>
										</div>
									</div>
									<?php
								endif;
							endwhile;
							wp_reset_postdata();
							?>
						</div>
						<?php
						if ( $enable_banner_dots ) :
							echo '<div class="swiper-pagination"></div>';
						endif;
						if ( $enable_banner_arrows ) :
							echo '<div class="swiper-button-next"></div><div class="swiper-button-prev"></div>';
						endif;
						?>
					</div>
				</div>
				<?php
				// Pinned Posts.
				if ( 'full-width' != $banner_layout && $enable_pinned_posts ) :
					$pinned_posts_cat = get_theme_mod( 'pinned_posts_cat', 1 );
					if ( ! empty( $pinned_posts_cat ) ) :
						$post_args   = array(
							'post_type'      => 'post',
							'posts_per_page' => 2,
							'post_status'    => 'publish',
							'tax_query'      => array(
								array(
									'taxonomy' => 'category',
									'field'    => 'term_id',
									'terms'    => absint( $pinned_posts_cat ),
								),
							),
						);
						$pinned_post = new WP_Query( $post_args );
						if ( $pinned_post->have_posts() ) :
							$show_pinned_posts_category = get_theme_mod( 'show_pinned_posts_category', true );
							if ( $show_pinned_posts_category ) {
								$pinned_posts_cat_style = get_theme_mod( 'pinned_posts_category_style', 'style_1' );
								$pinned_posts_cat_color = get_theme_mod( 'pinned_posts_category_color_display', 'none' );
								$pinned_posts_cat_limit = get_theme_mod( 'pinned_posts_category_limit', 2 );
							}
							$enable_pinned_posts_overlay = get_theme_mod( 'enable_pinned_posts_overlay', true );
							if ( $enable_pinned_posts_overlay ) {
								$pinned_posts_overlay_style  = 'background-color:' . esc_attr( get_theme_mod( 'pinned_posts_overlay_color', '#000000' ) ) . ';';
								$pinned_posts_overlay_style .= 'opacity:' . esc_attr( get_theme_mod( 'pinned_posts_overlay_opacity', 0.6 ) ) . ';';
							}
							$pinned_post_meta          = get_theme_mod( 'pinned_post_meta' );
							$pinned_post_meta_settings = array(
								'date_format'  => get_theme_mod( 'pinned_posts_date_format', 'format_2' ),
								'author_image' => get_theme_mod( 'enable_pinned_posts_author_image' ),
							);
							?>
							<div class="col co-lg-4">
								<?php
								$pinned_posts_title = get_theme_mod( 'pinned_posts_title' );
								if ( ! empty( $pinned_posts_title ) ) :
									$title_style = get_theme_mod( 'pinned_posts_title_style', 'style_1' );
									$title_align = 'has-text-align-' . get_theme_mod( 'pinned_posts_title_align', 'left' );
									?>
									<div class="saga-section-title">
										<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
											<span><?php echo esc_html( $pinned_posts_title ); ?></span>
										</h2>
									</div>
								<?php endif; ?>
								<div class="magazine-saga-pinned-posts-wrapper">
									<div class="magazine-saga-pinned-posts">
										<div class="row row-cols-1 row-cols-sm-2 row-cols-lg-1 g-3">
											<?php
											$title_limit = get_theme_mod( 'pinned_posts_title_limit' );
											while ( $pinned_post->have_posts() ) :
												$pinned_post->the_post();
												if ( has_post_thumbnail() ) :
													?>
													<div class="col">
														<div class="saga-block-item-w-overlay img-animate-zoom">
															<?php
															if ( get_theme_mod( 'show_pinned_posts_post_format_icon' ) ) {
																magazine_saga_post_format_icon();
															}
															?>
															<div class="saga-block-image-w-overlay">
																<a href="<?php the_permalink(); ?>" class="">
																	<?php if ( $enable_pinned_posts_overlay ) : ?>
																		<span aria-hidden="true" class="magazine-saga-block-overlay" style="<?php echo $pinned_posts_overlay_style; ?>"></span>
																	<?php endif; ?>
																	<?php the_post_thumbnail( 'magazine-saga-square-image' ); ?>
																</a>
															</div>
															<div class="saga-block-overlay-content">
																<?php
																if ( $show_pinned_posts_category ) :
																	magazine_saga_post_categories( $pinned_posts_cat_style, $pinned_posts_cat_color, $pinned_posts_cat_limit );
																endif;
																?>
																<h3 class="saga-block-overlay-title">
																	<a href="<?php the_permalink(); ?>" class="text-decoration-none  magazine-saga-limit-lines <?php echo esc_attr( $title_limit ); ?>">
																		<?php the_title(); ?>
																	</a>
																</h3>
																<?php magazine_saga_post_meta_info( $pinned_post_meta, $pinned_post_meta_settings ); ?>
															</div>
														</div>
													</div>
													<?php
												endif;
											endwhile;
											wp_reset_postdata();
											?>
										</div>
									</div>
								</div>
							</div>
							<?php
						endif;
					endif;
				endif;
				?>
			</div>
		</div>
	</section>       
	<?php
endif;
