<?php
$featured_posts_cat     = get_theme_mod( 'featured_posts_cat', 1 );
$featured_posts_orderby = get_theme_mod( 'featured_posts_orderby', 'date' );

// Covert id to ID to make it work with query
if ( 'id' == $featured_posts_orderby ) {
	$featured_posts_orderby = 'ID';
}

$post_args = array(
	'post_type'      => 'post',
	'posts_per_page' => absint( get_theme_mod( 'no_of_featured_posts', 6 ) ),
	'post_status'    => 'publish',
	'orderby'        => esc_attr( $featured_posts_orderby ),
	'order'          => esc_attr( get_theme_mod( 'featured_posts_order', 'desc' ) ),
);

if ( ! empty( $featured_posts_cat ) ) :
	$post_args['tax_query'] = array(
		array(
			'taxonomy' => 'category',
			'field'    => 'term_id',
			'terms'    => $featured_posts_cat,
		),
	);
endif;

$featured_post = new WP_Query( $post_args );
if ( $featured_post->have_posts() ) :

	$featured_posts_title  = get_theme_mod( 'featured_posts_title' );
	$enabled_post_meta     = get_theme_mod( 'featured_post_meta', array( 'date' ) );
	$enable_posts_desc     = get_theme_mod( 'enable_featured_posts_desc', true );
	$featured_posts_column = get_theme_mod( 'featured_posts_column', 3 );
	$show_category         = get_theme_mod( 'show_featured_posts_category', true );
	$enable_overlay        = get_theme_mod( 'enable_featured_posts_overlay', true );
	$title_limit           = get_theme_mod( 'featured_posts_title_limit' );

	$col_class = 'row row-cols-1 row-cols-sm-2 g-3';

	if ( 2 == $featured_posts_column ) {
		$col_class .= ' magazine-saga-grid-2';
	} elseif ( 3 == $featured_posts_column ) {
		$col_class .= ' row-cols-lg-3 magazine-saga-grid-3';
	} elseif ( 4 == $featured_posts_column ) {
		$col_class .= ' row-cols-xl-4 magazine-saga-grid-4';
	} elseif ( 5 == $featured_posts_column ) {
		$col_class .= ' row-cols-md-3 row-cols-lg-4 row-cols-xl-5 magazine-saga-grid-5';
	} else {
		$col_class .= ' row-cols-lg-3 magazine-saga-grid-3';
	}

	?>
	<section class="magazine-saga-section-block section-featured">
		<div class="wide-max-width">
			<?php
			if ( ! empty( $featured_posts_title ) ) :
				$title_style = get_theme_mod( 'featured_posts_title_style', 'style_2' );
				$title_align = 'has-text-align-' . get_theme_mod( 'featured_posts_title_align', 'left' );
				?>
				<div class="saga-section-title">
					<h2 class="saga-element-header <?php echo esc_attr( $title_style . ' ' . $title_align ); ?>">
						<span><?php echo esc_html( $featured_posts_title ); ?></span>
					</h2>
				</div>
			<?php endif; ?>
			<div class="saga-section-content">
				<div class="<?php echo esc_attr( $col_class ); ?>">
					<?php
					while ( $featured_post->have_posts() ) :
						$featured_post->the_post();
						if ( has_post_thumbnail() ) :
							?>
							<div class="col">
								<div class="saga-block-post-card magazine-saga-card-box img-animate-zoom">
									<div class="saga-block-item-w-overlay">
										<div class="saga-block-image-w-overlay">
											<a href="<?php the_permalink(); ?>" class="">
												<?php
												if ( get_theme_mod( 'show_featured_posts_post_format_icon' ) ) {
													magazine_saga_post_format_icon();
												}
												?>
												<?php
												if ( $enable_overlay ) :
													$style  = 'background-color:' . esc_attr( get_theme_mod( 'featured_posts_overlay_color', '#000000' ) ) . ';';
													$style .= 'opacity:' . esc_attr( get_theme_mod( 'featured_posts_overlay_opacity', 0.6 ) ) . ';';
													?>
													<span aria-hidden="true" class="magazine-saga-block-overlay" style="<?php echo $style; ?>"></span>
													<?php
												endif;
												?>
												<?php the_post_thumbnail( 'magazine-saga-large-img' ); ?>
											</a>
										</div>
										<div class="saga-block-overlay-content">
											<?php
											if ( $show_category ) :
												$cat_style = get_theme_mod( 'featured_posts_category_style', 'style_1' );
												$color     = get_theme_mod( 'featured_posts_category_color_display', 'none' );
												$limit     = get_theme_mod( 'featured_posts_category_limit', 3 );
												magazine_saga_post_categories( $cat_style, $color, $limit );
											endif;
											?>
										</div>
									</div>
									<div class="saga-block-card-content">
										<h3 class="saga-block-card-title no-margin">
											<a href="<?php the_permalink(); ?>" class="text-decoration-none color-accent-hover  magazine-saga-limit-lines <?php echo esc_attr( $title_limit ); ?>">
												<?php the_title(); ?>
											</a>
										</h3>
										<?php
										$meta_settings = array(
											'date_format'  => get_theme_mod( 'featured_posts_date_format', 'format_2' ),
											'author_image' => get_theme_mod( 'enable_featured_posts_author_image' ),
										);
										magazine_saga_post_meta_info( $enabled_post_meta, $meta_settings );
										?>
										<?php
										if ( $enable_posts_desc ) :
											$desc_length = absint( get_theme_mod( 'featured_posts_desc_length', 18 ) );
											?>
											<div class="saga-block-card-desc">
												<?php echo wp_trim_words( get_the_excerpt(), $desc_length, '&hellip;' ); ?>
											</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
							<?php
						endif;
					endwhile;
					wp_reset_postdata();
					?>
				</div>
			</div>
		</div>
	</section>
	<?php
endif;
